@@ -105,10 +105,18 @@ impl Expr for StringExpr {
     }
 }
 
+#[derive(PartialEq, Clone)]
+pub enum SymbolFlag {
+    AggregationReference,
+    WindowReference,
+    None,
+}
+
 #[derive(Clone)]
 pub struct SymbolExpr {
     pub value: String,
-    pub result_type: Box<dyn DataType>,
+    pub expr_type: Box<dyn DataType>,
+    pub flag: SymbolFlag,
 }
 
 impl Expr for SymbolExpr {
@@ -117,7 +125,7 @@ impl Expr for SymbolExpr {
     }
 
     fn expr_type(&self) -> Box<dyn DataType> {
-        self.result_type.clone()
+        self.expr_type.clone()
     }
 
     fn as_any(&self) -> &dyn Any {
