@@ -3,7 +3,7 @@ use super::values::base::Value;
 use gitql_ast::types::base::DataType;
 
 /// Standard function accept array of values and return single [`Value`]
-pub type Function = fn(&[Box<dyn Value>]) -> Box<dyn Value>;
+pub type StandardFunction = fn(&[Box<dyn Value>]) -> Box<dyn Value>;
 
 /// Aggregation function accept a selected row values for each row in group and return single [`Value`]
 ///
@@ -16,7 +16,20 @@ pub type Function = fn(&[Box<dyn Value>]) -> Box<dyn Value>;
 /// This implementation allow aggregation function to accept more than one parameter,
 /// and also accept any Expression not only field name
 ///
-pub type Aggregation = fn(Vec<Vec<Box<dyn Value>>>) -> Box<dyn Value>;
+pub type AggregationFunction = fn(&[Vec<Box<dyn Value>>]) -> Box<dyn Value>;
+
+/// Window function  a selected row values for each row in a specific frame and return single [`Value`]
+///
+/// [`Vec<Vec<Value>>`] represent the selected values from each row in frame of rows
+///
+/// For Example if we have three rows in frame of row and select name and email from each one
+///
+/// [[name, email], [name, email], [name, email]]
+///
+/// This implementation allow Window` function to accept more than one parameter,
+/// and also accept any Expression not only field name
+///
+pub type WindowFunction = fn(&[Vec<Box<dyn Value>>]) -> Vec<Box<dyn Value>>;
 
 /// Signature struct is a representation of function type
 ///
