@@ -17,6 +17,7 @@ use gitql_ast::statement::SelectStatement;
 use gitql_ast::statement::Statement;
 use gitql_ast::statement::StatementKind::*;
 use gitql_ast::statement::WhereStatement;
+use gitql_ast::statement::WindowFunctionsStatement;
 use gitql_core::environment::Environment;
 use gitql_core::object::GitQLObject;
 use gitql_core::object::Group;
@@ -31,6 +32,7 @@ use crate::engine_group::execute_group_by_statement;
 use crate::engine_join::apply_join_operation;
 use crate::engine_ordering::execute_order_by_statement;
 use crate::engine_output_into::execute_into_statement;
+use crate::engine_window_functions::execute_window_functions_statement;
 
 #[allow(clippy::borrowed_box)]
 pub fn execute_statement(
@@ -89,7 +91,13 @@ pub fn execute_statement(
                 .as_any()
                 .downcast_ref::<OrderByStatement>()
                 .unwrap();
-            execute_order_by_statement(env, statement, gitql_object)
+
+            if gitql_object.len() > 1 {
+                gitql_object.flat();
+            }
+
+            let main_group_index = 0;
+            execute_order_by_statement(env, statement, gitql_object, main_group_index)
         }
         GroupBy => {
             let statement = statement
@@ -103,7 +111,7 @@ pub fn execute_statement(
                 .as_any()
                 .downcast_ref::<AggregationsStatement>()
                 .unwrap();
-            execute_aggregation_function_statement(
+            execute_aggregation_functions_statement(
                 env,
                 statement,
                 gitql_object,
@@ -111,6 +119,13 @@ pub fn execute_statement(
                 has_group_by_statement,
             )
         }
+        WindowFunction => {
+            let statement = statement
+                .as_any()
+                .downcast_ref::<WindowFunctionsStatement>()
+                .unwrap();
+            execute_window_functions_statement(env, statement, gitql_object, alias_table)
+        }
         Into => {
             let statement = statement.as_any().downcast_ref::<IntoStatement>().unwrap();
             execute_into_statement(statement, gitql_object)
@@ -171,7 +186,7 @@ fn execute_select_statement(
         // Calculate list of titles once per table
         let mut table_titles = vec![];
         for selected_column in selected_columns.iter_mut() {
-            table_titles.push(get_column_name(alias_table, selected_column));
+            table_titles.push(resolve_actual_column_name(alias_table, selected_column));
         }
 
         // Call the provider only if table name is not empty
@@ -277,16 +292,16 @@ fn execute_where_statement(
     statement: &WhereStatement,
     gitql_object: &mut GitQLObject,
 ) -> Result<(), String> {
-    // Perform where command only on the first group
-    // because group by command not executed yet
-    let condition = &statement.condition;
-    let main_group = &gitql_object.groups.first().unwrap().rows;
-    let rows = apply_filter_operation(env, condition, &gitql_object.titles, main_group)?;
-    let filtered_group: Group = Group { rows };
+    if gitql_object.is_empty() {
+        return Ok(());
+    }
 
-    // Update the main group with the filtered data
-    gitql_object.groups.remove(0);
-    gitql_object.groups.push(filtered_group);
+    apply_filter_operation(
+        env,
+        &statement.condition,
+        &gitql_object.titles,
+        &mut gitql_object.groups[0].rows,
+    )?;
 
     Ok(())
 }
@@ -306,14 +321,12 @@ fn execute_having_statement(
 
     // Perform where command only on the first group
     // because group by command not executed yet
-    let condition = &statement.condition;
-    let main_group = &gitql_object.groups.first().unwrap().rows;
-    let rows = apply_filter_operation(env, condition, &gitql_object.titles, main_group)?;
-    let filtered_group: Group = Group { rows };
-
-    // Update the main group with the filtered data
-    gitql_object.groups.remove(0);
-    gitql_object.groups.push(filtered_group);
+    apply_filter_operation(
+        env,
+        &statement.condition,
+        &gitql_object.titles,
+        &mut gitql_object.groups[0].rows,
+    )?;
 
     Ok(())
 }
@@ -358,7 +371,7 @@ fn execute_offset_statement(
     Ok(())
 }
 
-fn execute_aggregation_function_statement(
+fn execute_aggregation_functions_statement(
     env: &mut Environment,
     statement: &AggregationsStatement,
     gitql_object: &mut GitQLObject,
@@ -379,13 +392,10 @@ fn execute_aggregation_function_statement(
         }
 
         // Resolve all aggregations functions first
-        for aggregation in aggregations_map {
-            if let AggregateValue::Function(function, arguments) = aggregation.1 {
+        for (result_column_name, aggregation) in aggregations_map {
+            if let AggregateValue::Function(function, arguments) = aggregation {
                 // Get alias name if exists or column name by default
-
-                let result_column_name = aggregation.0;
-                let column_name = get_column_name(alias_table, result_column_name);
-
+                let column_name = resolve_actual_column_name(alias_table, result_column_name);
                 let column_index = gitql_object
                     .titles
                     .iter()
@@ -393,7 +403,7 @@ fn execute_aggregation_function_statement(
                     .unwrap();
 
                 // Evaluate the Arguments to Values
-                let mut group_values: Vec<Vec<Box<dyn Value>>> =
+                let mut group_arguments: Vec<Vec<Box<dyn Value>>> =
                     Vec::with_capacity(group.rows.len());
                 for object in &mut group.rows {
                     let mut row_values: Vec<Box<dyn Value>> =
@@ -409,12 +419,12 @@ fn execute_aggregation_function_statement(
                         row_values.push(value);
                     }
 
-                    group_values.push(row_values);
+                    group_arguments.push(row_values);
                 }
 
                 // Get the target aggregation function
-                let aggregation_function = env.aggregation_function(function.as_str()).unwrap();
-                let result = &aggregation_function(group_values);
+                let aggregation_function = env.aggregation_function(function).unwrap();
+                let result = &aggregation_function(&group_arguments);
 
                 // Insert the calculated value in the group objects
                 for object in &mut group.rows {
@@ -428,12 +438,10 @@ fn execute_aggregation_function_statement(
         }
 
         // Resolve aggregations expressions
-        for aggregation in aggregations_map {
-            if let AggregateValue::Expression(expr) = aggregation.1 {
+        for (result_column_name, aggregation) in aggregations_map {
+            if let AggregateValue::Expression(expr) = aggregation {
                 // Get alias name if exists or column name by default
-                let result_column_name = aggregation.0;
-                let column_name = get_column_name(alias_table, result_column_name);
-
+                let column_name = resolve_actual_column_name(alias_table, result_column_name);
                 let column_index = gitql_object
                     .titles
                     .iter()
@@ -473,9 +481,10 @@ pub fn execute_global_variable_statement(
 }
 
 #[inline(always)]
-pub fn get_column_name(alias_table: &HashMap<String, String>, name: &str) -> String {
-    alias_table
-        .get(name)
-        .unwrap_or(&name.to_string())
-        .to_string()
+pub fn resolve_actual_column_name(alias_table: &HashMap<String, String>, name: &str) -> String {
+    if let Some(column_name) = alias_table.get(name) {
+        return column_name.to_string();
+    }
+
+    name.to_string()
 }
