@@ -1,10 +1,11 @@
 pub mod aggregation;
 pub mod array;
 pub mod datetime;
-pub mod function;
 pub mod general;
 pub mod meta_types;
 pub mod number;
 pub mod range;
 pub mod regex;
+pub mod standard;
 pub mod text;
+pub mod window;
